@@ -66,7 +66,7 @@ scheme = openapi.Parameter(
 style = openapi.Parameter(
     'style',
     openapi.IN_QUERY,
-    description='Encoded string of JSON style following https://girder.github.io/large_image/tilesource_options.html#style . This can optionally be Base64 encoded if too large for URL.',
+    description='Encoded string of JSON style following https://girder.github.io/large_image/tilesource_options.html#style',
     type=openapi.TYPE_STRING,
 )
 
@@ -120,3 +120,22 @@ format = openapi.Parameter(
 )
 
 HISTOGRAM = [only, bins, density, format]
+
+
+# Thumbnail Parameters
+max_width = openapi.Parameter(
+    'max_width',
+    openapi.IN_QUERY,
+    description='maximum width in pixels.',
+    type=openapi.TYPE_INTEGER,
+    default=256,
+)
+max_height = openapi.Parameter(
+    'max_height',
+    openapi.IN_QUERY,
+    description='maximum height in pixels.',
+    type=openapi.TYPE_INTEGER,
+    default=256,
+)
+
+THUMBNAIL = [max_height, max_width]
